import setuptools


def readme():
    with open("README.md") as f:
        return f.read()
    

setuptools.setup(
    name="ClappScrapers",
    version="0.1.3",
    description="Clappform Python scraper",
    author = "Clappform B.V.",
    author_email = "info@clappform.com",
    long_description=readme(),
    long_description_content_type="text/markdown",

    license="MIT",
    url = "https://github.com/ClappFormOrg/clappform-scraper",
    classifiers = [
    "Development Status :: 4 - Beta",
    "License :: OSI Approved :: MIT License",
    "Programming Language :: Python :: 3",
    "Operating System :: OS Independent",
    ],
    keywords="scraper",
    python_requires = ">=3.10",
    install_requires = ['scrapy'],
    include_package_data=True,
    exclude_package_data={"":['*.egg-info','build','dist'],'ClappScrapers':['__pycache__'],},

    
)
